@@ -1,12 +1,8 @@
 package Kwiki::Base;
-use strict;
-use warnings;
-use Spoon::Base '-Base';
+use Spoon::Base -Base;
 
 field 'id';
 
-1;
-
 __END__
 
 =head1 NAME 
