@@ -72,6 +72,7 @@ sub default_classes {
         files_class => 'Kwiki::Files',
         formatter_class => 'Kwiki::Formatter',
         headers_class => 'Spoon::Headers',
+        hooks_class => 'Spoon::Hooks',
         hub_class => 'Kwiki::Hub',
         javascript_class => 'Kwiki::Javascript',
         pages_class => 'Kwiki::Pages',
@@ -169,6 +170,10 @@ See http://www.perl.com/perl/misc/Artistic.html
 =cut
 
 __config/config.yaml__
+# DO NOT EDIT THIS FILE
+# Put overrides in the top level config.yaml
+# See: http://www.kwiki.org/?ChangingConfigDotYaml
+#
 site_title: Kwiki
 main_page: HomePage
 database_directory: database
@@ -182,15 +187,112 @@ __!config.yaml__
 #
 logo_image: palm90.png
 __!plugins__
-# This is a list of all the plugins your Kwiki is currently set up to use.
-# Modify this list to suit your needs. After modification, run 'kwiki -update'
-# to make the changes live. Alternately use 'kwiki -add ...', 
-# 'kwiki -remove ...', and 'kwiki -install ...' to manage this list for you.
-# See http://www.kwiki.org/InstallingPlugins
-#
+# This is a list of all the plugins your Kwiki is currently set up to
+# use. Modify this list to suit your needs. After modification, run
+# 'kwiki -update' to make the changes live. Alternately use 
+# 'kwiki -add ...', 'kwiki -remove ...', and 'kwiki -install ...' to
+# manage this list for you.
+
+# See http://www.kwiki.org/InstallingPlugins for more information.
+
+# These are the bare bones plugins necessary for an editable Kwiki:
 Kwiki::Display
 Kwiki::Edit
 Kwiki::Theme::Basic
 Kwiki::Toolbar
 Kwiki::Status
 Kwiki::Widgets
+
+# These are very common plugins. You'll need to install them (as
+# separate CPAN modules) first.
+# Kwiki::RecentChanges
+# Kwiki::Archive::Rcs
+# Kwiki::Revisions
+# Kwiki::UserPreferences
+# Kwiki::UserName
+# Kwiki::Search
+# Kwiki::Icons::Gnome
+# Kwiki::TimeZone
+# Kwiki::NewPage
+# Kwiki::BreadCrumbs
+
+# Theme plugins:
+# Kwiki::Theme::Basic
+# Kwiki::Theme::Klassik
+# Kwiki::Theme::ColumnLayout
+# Kwiki::Theme::HLB
+# Kwiki::Theme::TabNav
+
+# Icon Set plugins:
+# Kwiki::Icons::Gnome
+# Kwiki::Icons::Crystal
+
+# Archive plugins:
+# Kwiki::Archive::Rcs
+# Kwiki::Archive::SVK
+# Kwiki::Archive::Cvs
+
+# WARNING: THIS FOLOWING SECTION OF PLUGINS SHOULD NOT BE MADE AVAILABLE
+# TO A PUBLICLY ACCESSABLE SITE! They offer capabilities which only the
+# site administrator should have access to. Install these plugins in a
+# password protected view of your kwiki. See
+# http://www.kwiki.org/AdminView for more information.
+#
+# Site Administrator plugins:
+# Kwiki::DeletePage
+# Kwiki::PageInfo
+# Kwiki::PagePrivacy
+
+# Anti WikiSpam plugins:
+# Kwiki::ExternalLinkWhitelist
+# Kwiki::AccessBlacklist
+# Kwiki::Scode
+
+# WAFL Syntax Extension plugins:
+# Kwiki::Comments
+# Kwiki::ConfigBlocks
+# Kwiki::DMOZLink
+# Kwiki::GoogleLink
+# Kwiki::IRCMode
+# Kwiki::Image
+# Kwiki::ParagraphBlocks
+# Kwiki::PerlTidyBlocks
+# Kwiki::PerlTidyModule
+# Kwiki::PodBlocks
+# Kwiki::PreformattedBlocks
+# Kwiki::ShellBlocks
+# Kwiki::ShortcutLinks
+# Kwiki::VimMode
+
+# Other plugins:
+# Kwiki::Atom
+# Kwiki::AuthorOnlyPageEditing
+# Kwiki::Autoformat
+# Kwiki::Diff
+# Kwiki::Edit::RequireUserName
+# Kwiki::Edit::SubEtha
+# Kwiki::Email
+# Kwiki::Favorites
+# Kwiki::GDGraphGenerator
+# Kwiki::GuestBook
+# Kwiki::HanConvert
+# Kwiki::Infobox
+# Kwiki::LiveSearch
+# Kwiki::MindMap
+# Kwiki::ModPerl
+# Kwiki::Notify::IRC
+# Kwiki::Notify::Mail
+# Kwiki::Outline2Html
+# Kwiki::PageInclude
+# Kwiki::PagePrivacy
+# Kwiki::PageTemplate
+# Kwiki::Pages::Perldoc
+# Kwiki::RecentChanges::Atom
+# Kwiki::RecentChangesRSS
+# Kwiki::ReferrerLog
+# Kwiki::SocialMap
+# Kwiki::Spork
+# Kwiki::Toolbar::List
+# Kwiki::Users::Remote
+# Kwiki::Weather
+# Kwiki::Zipcode
